import os
# this file is used to create instances of the classes in the utilspkg folder: DB, Slack, GPT, etc.
from utilspkg import utils_db, utils_slack, utils_gpt


class Connections:
    def __init__(self, testing_flag):
        self.db_connection = utils_db.DBConnect()
        self.slack_connection = utils_slack.SlackConnect(testing_flag=testing_flag)
        self.gpt_connection = utils_gpt.GPTConnect()


# You can create an instance of this class in your main file
connections = None

def initialize_connections(testing_flag=None):
    # print("In utils_connections: initialize_connections()")
    global connections
    # if testing_flag is none, check if env variable is set:
    if testing_flag is None:
        testing_flag = os.getenv("TESTING_FLAG") #TESTING_FLAG
    connections = Connections(testing_flag)

def get_connections(testing_flag=None):
    # print("In utils_connections: get_connections()")
    global connections
    if connections is None:
        initialize_connections(testing_flag = testing_flag)  
    return connections.db_connection, connections.slack_connection, connections.gpt_connection




import os
import sys
from setuptools import setup, find_packages

os.chdir('./utilsfolder')

if '--version' in sys.argv:
    version_index = sys.argv.index('--version') + 1
    version = sys.argv[version_index]
    sys.argv.remove('--version')
    sys.argv.remove(version)
else:
    version = input("Please enter the version number in 0.0.0 format: ")

if not version:
    print("Skipping utilspkg upload (not an error).")
    sys.exit(0)  # Exit with status code 0 which means success

setup(
    name='utilspkg',
    version=version, # takes the version variable from the command line
    packages=find_packages(include=['utilspkg']),
    install_requires=[ # install_requires are not used when compiling. they are referenced when pip installs this package to ensure they're also installed. so important but not critical for me.
        'airtable-python-wrapper>=0.15.3',
        'openai>=0.27.7',
        'protobuf>=4.24.1',
        'python-dotenv>=1.0.0',
        'pytz>=2023.3',
        'slack-sdk>=3.21.3',
        'tenacity>=8.2.2',
        'PyYAML',
        'google-cloud-logging'
    ]
)


